/*  Hint file for the IRIX platform, ncurses version of libncurses,
 *  tested for IRIX 6.2.
 *
 *  If this configuration doesn't work, look at the file "c-none.h"
 *  for how to set the configuration options.
 */

/* Roland Walker <walker@ncbi.nlm.nih.gov> Feb 1999*/

#include <ncurses.h>

#ifdef C_PANELSUPPORT
#include <panel.h>
#endif

#ifdef C_MENUSUPPORT
#include <menu.h>
#endif

#ifdef C_FORMSUPPORT
#include <form.h>
#endif

/* Defined in both Perl & Ncurses */
#undef instr

#define C_LONGNAME
#define C_LONG0ARGS
#undef  C_LONG2ARGS

#define C_TOUCHLINE
#define C_TOUCH3ARGS
#undef  C_TOUCH4ARGS
